<?php
/*
Plugin Name: Easy Currency Converter
Plugin URI: https://easycurrencyconverter.net
Description: Plugin for currency convertion
Author URI: https://easycurrencyconverter.net
Tested up to: 5.2.2
License: http://www.gnu.org/licenses/gpl-2.0.html
Author: Easy Currency Converter
Version: 1.4
*/

// Post Type Registration
add_action( 'init', 'ecc_converter_register_posttype' );

function ecc_converter_register_posttype() {

	$labels = array(
		'name'               => __('Converter Block', ECC_PLG_NAME),
		'singular_name'      => __('Converter Block', ECC_PLG_NAME),
		'add_new'            => __('Add New', ECC_PLG_NAME),
		'add_new_item'       => __('Add New Converter', ECC_PLG_NAME),
		'edit_item'          => __('Edit Converter', ECC_PLG_NAME),
		'new_item'           => __('New Converter', ECC_PLG_NAME),
		'all_items'          => __('All Converters', ECC_PLG_NAME),
		'view_item'          => __('View Converter', ECC_PLG_NAME),
		'search_items'       => __('Search Converter', ECC_PLG_NAME),
		'not_found'          => __('No converter found', ECC_PLG_NAME),
		'not_found_in_trash' => __('No conterver found in Trash', ECC_PLG_NAME),
		'parent_item_colon'  => '',
		'menu_name'          => __('Converter', ECC_PLG_NAME)
	  );

	  $args = array(
		'labels'             => $labels,
		'public'             => true,
		'publicly_queryable' => true,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'query_var'          => true,
		'rewrite'            => array( 'slug' => 'ecc-converter' ),
		'capability_type'    => 'post',
		'show_in_rest'       => true,
		'has_archive'        => true,
		'hierarchical'       => false,
		'menu_position'      => null,
		'menu_icon'          => ECC_URL.'assets/img/converter_icon.png',
		'supports'           => array( 'title')
	  );

	  register_post_type( 'ecc-converters', $args );

}


// Post Type custom column -> [shortcode]
add_filter('manage_edit-ecc-converters_columns', 'ecc_add_new_converters_columns');

function ecc_add_new_converters_columns( $columns ) {

    $columns['shortcode'] = __( 'Shortcode', FF_PLG_NAME );
    return $columns;

}

add_action( 'manage_ecc-converters_posts_custom_column', 'ecc_shortcode_column_display', 10, 2 );

function ecc_shortcode_column_display( $column_name, $post_id ) {

    if ( 'shortcode' != $column_name ) {
        return;
    }

    echo '<input type="text" onclick="select()" readonly="readonly" value="[ecc_converter id='.$post_id.']" style="background:none; border:none; box-shadow:none; color:#0074A2; width:300px; font-size:16px; line-height:40px;">';

}



// Post Type custom messages
add_filter( 'post_updated_messages', 'ecc_projects_custom_messages' );

function ecc_projects_custom_messages( $messages ) {

  global $post, $post_ID;

  $messages['ecc-projects'] = array(
    0 => '', // Unused. Messages start at index 1.
    1 => sprintf( __('Project updated. <a href="%s">View project</a>', ECC_PLG_NAME), esc_url( get_permalink($post_ID) ) ),
    2 => __('Custom field updated.', ECC_PLG_NAME),
    3 => __('Custom field deleted.', ECC_PLG_NAME),
    4 => __('Project updated.', ECC_PLG_NAME),
    /* translators: %s: date and time of the revision */
    5 => isset($_GET['revision']) ? sprintf( __('Project restored to revision from %s', ECC_PLG_NAME), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
    6 => sprintf( __('Project published. <a href="%s">View project</a>', ECC_PLG_NAME), esc_url( get_permalink($post_ID) ) ),
    7 => __('Project saved.', ECC_PLG_NAME),
    8 => sprintf( __('Project submitted. <a target="_blank" href="%s">Preview project</a>', ECC_PLG_NAME), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
    9 => sprintf( __('Project scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview project</a>', ECC_PLG_NAME),
      // translators: Publish box date format, see http://php.net/date
      date_i18n( __( 'M j, Y @ G:i', ECC_PLG_NAME ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
    10 => sprintf( __('Project draft updated. <a target="_blank" href="%s">Preview project</a>', ECC_PLG_NAME), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
  );

  return $messages;

}

